<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class Gauges {

	/**
	 * The single instance of Gauges.
	 * @var 	object
	 * @access  private
	 * @since 	1.0.0
	 */
	private static $_instance = null;

	/**
	 * Settings class object
	 * @var     object
	 * @access  public
	 * @since   1.0.0
	 */
	public $settings = null;

	/**
	 * The version number.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $_version;

	/**
	 * The token.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $_token;

	/**
	 * The main plugin file.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $file;

	/**
	 * The main plugin directory.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $dir;

	/**
	 * The plugin assets directory.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $assets_dir;

	/**
	 * The plugin assets URL.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $assets_url;

	/**
	 * Suffix for Javascripts.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $script_suffix;

	/**
	 * Constructor function.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function __construct ( $file = '', $version = '1.0.0' ) {
		$this->_version = $version;
		$this->_token = 'gauges';

		// Load plugin environment variables
		$this->file = $file;
		$this->dir = dirname( $this->file );
		$this->assets_dir = trailingslashit( $this->dir ) . 'assets';
		$this->assets_url = esc_url( trailingslashit( plugins_url( '/assets/', $this->file ) ) );

		$this->script_suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		// Load tracking script
		add_action('init', array( $this, 'enqueue_tracker' ));
		
	
		// Load admin JS & CSS
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ), 10, 1 );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_styles' ), 10, 1 );
		
		

		// Load API for generic admin functions
		if ( is_admin() ) {
			$this->admin = new Gauges_Admin_API();
		}else{

		}

	} // End __construct ()

	/**
	 * Check if logged in user is end user
	 * @access  public
	 * @since   1.0.0
	 * @return  int
	 */
	function user_logged_in () {
	  $current_user = wp_get_current_user();
	  return is_user_logged_in() && !in_array('administrator', $current_user->roles);
	}

	/**
	 * Check if logged in user is admin
	 * @access  public
	 * @since   1.0.0
	 * @return  int
	 */
	function admin_logged_in () {
	  $current_user = wp_get_current_user();
	  return in_array('administrator', $current_user->roles);
	}

	/**
	 * Load frontend Javascript tracker.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function enqueue_tracker () {
		$options = $this->get_options();
		$track_logged_in_users = $options['track_logged_in_users'];
		$is_admin = $this->admin_logged_in();

		if($this->admin_logged_in() != 1 ){
			if(!$track_logged_in_users && $this->user_logged_in()){
				return;
			}

			add_action( 'wp_head', array( $this, 'load_tracking_script'), 2 );
		}
	}


	/**
	 * Load admin CSS.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function admin_enqueue_styles ( $hook = '' ) {
		wp_register_style( $this->_token . '-admin', esc_url( $this->assets_url ) . 'css/admin.css', array(), $this->_version );
		wp_enqueue_style( $this->_token . '-admin' );
	} // End admin_enqueue_styles ()

	/**
	 * Load admin Javascript.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function admin_enqueue_scripts ( $hook = '' ) {
		wp_register_script( $this->_token . '-admin', esc_url( $this->assets_url ) . 'js/admin' . $this->script_suffix . '.js', array( 'jquery' ), $this->_version );
		wp_enqueue_script( $this->_token . '-admin' );
	} // End admin_enqueue_scripts ()

	
	/**
	 * Load admin CSS.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function load_tracking_script () {
		$options = $this->get_options();
		$site_id = $options['site_id'];

		$script =  "<script type='text/javascript'>
					  var _gauges = _gauges || [];
					  (function() {
					    var t   = document.createElement('script');
					    t.type  = 'text/javascript';
					    t.async = true;
					    t.id    = 'gauges-tracker';
					    t.setAttribute('data-site-id', '$site_id');
					    t.setAttribute('data-track-path', 'https://track.gaug.es/track.gif');
					    t.src = 'https://d2fuc4clr7gvcn.cloudfront.net/track.js';
					    var s = document.getElementsByTagName('script')[0];
					    s.parentNode.insertBefore(t, s);
					  })();
					</script>";

		if($site_id){
			echo $script;
		}
		
		return;
	}

	private function get_options() {
		
		$prefix = $this->_token;
		return [
			"site_id" => esc_attr(get_option($prefix."_site_id")),
			"track_logged_in_users" => esc_attr(get_option($prefix."_track_logged_in_users")),
		];
	}
	/**
	 * Main Gauges Instance
	 *
	 * Ensures only one instance of Gauges is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @static
	 * @see Gauges()
	 * @return Main Gauges instance
	 */
	public static function instance ( $file = '', $version = '1.0.0' ) {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self( $file, $version );
		}
		return self::$_instance;
	} // End instance ()

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __clone () {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), $this->_version );
	} // End __clone ()

	/**
	 * Unserializing instances of this class is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __wakeup () {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), $this->_version );
	} // End __wakeup ()

	/**
	 * Installation. Runs on activation.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function install () {
		$this->_log_version_number();
	} // End install ()

	/**
	 * Log the plugin version number.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	private function _log_version_number () {
		update_option( $this->_token . '_version', $this->_version );
	} // End _log_version_number ()

}
